pub fn get_default_instance(config: &Config) -> &JumpStartInstanceExpand description
Get the default instance, or the first instance if none is marked default
pub fn get_default_instance(config: &Config) -> &JumpStartInstanceGet the default instance, or the first instance if none is marked default